<?php
/*
 * @copyright 2023 Passwords Handbook App
 *
 * @author Marius David Wieschollek
 * @license AGPL-3.0
 *
 * This file is part of the Passwords App
 * created by Marius David Wieschollek.
 */

namespace OCA\PasswordsHandbook\Settings;

use OCA\PasswordsHandbook\Service\FeaturesService;
use OCA\PasswordsHandbook\Service\HandbookUrlService;
use OCA\PasswordsHandbook\Service\SetupCheckService;
use OCP\AppFramework\Http\TemplateResponse;
use OCP\Settings\ISettings;

class AdminSettings implements ISettings {
    public function __construct(
        protected HandbookUrlService $handbookUrlService,
        protected SetupCheckService  $setupCheckService,
        protected FeaturesService    $featuresService
    ) {
    }

    public function getForm() {
        return new TemplateResponse(
            'passwords_handbook',
            'admin/settings',
            [
                'enabled'  => $this->handbookUrlService->isUrlSet(),
                'url'      => $this->handbookUrlService->getCurrentUrl(),
                'error'    => $this->setupCheckService->check(),
                'features' => $this->featuresService->getFeatures()
            ]
        );
    }

    public function getSection() {
        return 'passwords';
    }

    public function getPriority() {
        return 20;
    }
}